aboutsummaryrefslogtreecommitdiffstats
path: root/view/js/autocomplete.js
diff options
context:
space:
mode:
Diffstat (limited to 'view/js/autocomplete.js')
-rw-r--r--view/js/autocomplete.js44
1 files changed, 33 insertions, 11 deletions
diff --git a/view/js/autocomplete.js b/view/js/autocomplete.js
index 8572cf708..40a9cd4c8 100644
--- a/view/js/autocomplete.js
+++ b/view/js/autocomplete.js
@@ -5,11 +5,16 @@
*/
function contact_search(term, callback, backend_url, type, extra_channels) {
// Check if there is a cached result that contains the same information we would get with a full server-side search
- // Assume type hasn't changed
- for(t in contact_search.cache) {
- if(term.indexOf(t) >= 0) { // A more broad search has been performed already, so use those results
+
+ var bt = backend_url+type;
+ if(!(bt in contact_search.cache)) contact_search.cache[bt] = {};
+
+ var lterm = term.toLowerCase(); // Ignore case
+ for(t in contact_search.cache[bt]) {
+ if(lterm.indexOf(t) >= 0) { // A more broad search has been performed already, so use those results
// Filter old results locally
- var matching = contact_search.cache[t].filter(function (x) { return (x.name.indexOf(term) >= 0 || x.nick.indexOf(term) >= 0); });
+ var matching = contact_search.cache[bt][t].filter(function (x) { return (x.name.toLowerCase().indexOf(lterm) >= 0 || x.nick.toLowerCase().indexOf(lterm) >= 0); });
+ matching.unshift({taggable:false, text: term, replace: term});
callback(matching);
return;
}
@@ -33,20 +38,34 @@ function contact_search(term, callback, backend_url, type, extra_channels) {
success:function(data){
// Cache results if we got them all (more information would not improve results)
// data.count represents the maximum number of items
- if(data.items.length < data.count) {
- contact_search.cache[term] = data.items;
+ if(data.items.length -1 < data.count) {
+ contact_search.cache[bt][lterm] = data.items;
}
- callback(data.items);
+ var items = data.items.slice(0);
+ items.unshift({taggable:false, text: term, replace: term});
+ callback(items);
},
}).fail(function () {callback([]); }); // Callback must be invoked even if something went wrong.
}
contact_search.cache = {};
+
function contact_format(item) {
- return "<div class='{0}' title='{4}'><img src='{1}'>{2} ({3})</div>".format(item.taggable, item.photo, item.name, ((item.label) ? item.nick + ' ' + item.label : item.nick), item.link )
+ // Show contact information if not explicitly told to show something else
+ if(typeof item.text === 'undefined') {
+ var desc = ((item.label) ? item.nick + ' ' + item.label : item.nick)
+ if(desc) desc = ' ('+desc+')';
+ return "<div class='{0}' title='{4}'><img src='{1}'>{2}{3}</div>".format(item.taggable, item.photo, item.name, desc, item.link)
+ }
+ else
+ return "<div>"+item.text+"</div>"
}
function editor_replace(item) {
+ if(typeof item.replace !== 'undefined') {
+ return '$1$2'+item.replace;
+ }
+
// $2 ensures that prefix (@,@!) is preserved
var id = item.id;
// 16 chars of hash should be enough. Full hash could be used if it can be done in a visually appealing way.
@@ -57,6 +76,9 @@ function editor_replace(item) {
}
function basic_replace(item) {
+ if(typeof item.replace !== 'undefined')
+ return '$1'+item.replace;
+
return '$1'+item.name+' ';
}
@@ -88,7 +110,7 @@ function submit_form(e) {
replace: function(item) { return "$1"+item['text'] + ' '; },
}
this.attr('autocomplete','off');
- this.textcomplete([contacts,smilies],{className:'acpopup'});
+ this.textcomplete([contacts,smilies],{className:'acpopup',zIndex:1050});
};
})( jQuery );
@@ -107,7 +129,7 @@ function submit_form(e) {
template: contact_format,
}
this.attr('autocomplete','off');
- var a = this.textcomplete([contacts],{className:'acpopup',maxCount:100});
+ var a = this.textcomplete([contacts],{className:'acpopup',maxCount:100,zIndex: 1050});
a.on('textComplete:select', function(e,value,strategy) { submit_form(this); });
@@ -130,7 +152,7 @@ function submit_form(e) {
}
this.attr('autocomplete','off');
- var a = this.textcomplete([contacts],{className:'acpopup'});
+ var a = this.textcomplete([contacts],{className:'acpopup',zIndex:1050});
if(autosubmit)
a.on('textComplete:select', function(e,value,strategy) { submit_form(this); });